==> aws-cdk-scala_2.13-0.14.0-sources.jar: io/burkard/cdk/services/appflow/cfnFlow/DestinationConnectorPropertiesProperty.scala <==
package io.burkard.cdk.services.appflow.cfnFlow

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object DestinationConnectorPropertiesProperty {

  def apply(
    lookoutMetrics: Option[software.amazon.awscdk.services.appflow.CfnFlow.LookoutMetricsDestinationPropertiesProperty] = None,
    s3: Option[software.amazon.awscdk.services.appflow.CfnFlow.S3DestinationPropertiesProperty] = None,
    upsolver: Option[software.amazon.awscdk.services.appflow.CfnFlow.UpsolverDestinationPropertiesProperty] = None,
    eventBridge: Option[software.amazon.awscdk.services.appflow.CfnFlow.EventBridgeDestinationPropertiesProperty] = None,
    zendesk: Option[software.amazon.awscdk.services.appflow.CfnFlow.ZendeskDestinationPropertiesProperty] = None,
    redshift: Option[software.amazon.awscdk.services.appflow.CfnFlow.RedshiftDestinationPropertiesProperty] = None,
    salesforce: Option[software.amazon.awscdk.services.appflow.CfnFlow.SalesforceDestinationPropertiesProperty] = None,
    snowflake: Option[software.amazon.awscdk.services.appflow.CfnFlow.SnowflakeDestinationPropertiesProperty] = None
  ): software.amazon.awscdk.services.appflow.CfnFlow.DestinationConnectorPropertiesProperty =
    (new software.amazon.awscdk.services.appflow.CfnFlow.DestinationConnectorPropertiesProperty.Builder)
      .lookoutMetrics(lookoutMetrics.orNull)
      .s3(s3.orNull)
      .upsolver(upsolver.orNull)
      .eventBridge(eventBridge.orNull)
      .zendesk(zendesk.orNull)
      .redshift(redshift.orNull)
      .salesforce(salesforce.orNull)
      .snowflake(snowflake.orNull)
      .build()
}

==> aws-cdk-scala_2.13-0.22.0-sources.jar: io/burkard/cdk/services/appflow/cfnFlow/DestinationConnectorPropertiesProperty.scala <==
package io.burkard.cdk.services.appflow.cfnFlow

@SuppressWarnings(Array("org.wartremover.warts.DefaultArguments", "org.wartremover.warts.Null", "DisableSyntax.null"))
object DestinationConnectorPropertiesProperty {

  def apply(
    lookoutMetrics: Option[software.amazon.awscdk.services.appflow.CfnFlow.LookoutMetricsDestinationPropertiesProperty] = None,
    s3: Option[software.amazon.awscdk.services.appflow.CfnFlow.S3DestinationPropertiesProperty] = None,
    upsolver: Option[software.amazon.awscdk.services.appflow.CfnFlow.UpsolverDestinationPropertiesProperty] = None,
    customConnector: Option[software.amazon.awscdk.services.appflow.CfnFlow.CustomConnectorDestinationPropertiesProperty] = None,
    eventBridge: Option[software.amazon.awscdk.services.appflow.CfnFlow.EventBridgeDestinationPropertiesProperty] = None,
    zendesk: Option[software.amazon.awscdk.services.appflow.CfnFlow.ZendeskDestinationPropertiesProperty] = None,
    sapoData: Option[software.amazon.awscdk.services.appflow.CfnFlow.SAPODataDestinationPropertiesProperty] = None,
    marketo: Option[software.amazon.awscdk.services.appflow.CfnFlow.MarketoDestinationPropertiesProperty] = None,
    redshift: Option[software.amazon.awscdk.services.appflow.CfnFlow.RedshiftDestinationPropertiesProperty] = None,
    salesforce: Option[software.amazon.awscdk.services.appflow.CfnFlow.SalesforceDestinationPropertiesProperty] = None,
    snowflake: Option[software.amazon.awscdk.services.appflow.CfnFlow.SnowflakeDestinationPropertiesProperty] = None
  ): software.amazon.awscdk.services.appflow.CfnFlow.DestinationConnectorPropertiesProperty =
    (new software.amazon.awscdk.services.appflow.CfnFlow.DestinationConnectorPropertiesProperty.Builder)
      .lookoutMetrics(lookoutMetrics.orNull)
      .s3(s3.orNull)
      .upsolver(upsolver.orNull)
      .customConnector(customConnector.orNull)
      .eventBridge(eventBridge.orNull)
      .zendesk(zendesk.orNull)
      .sapoData(sapoData.orNull)
      .marketo(marketo.orNull)
      .redshift(redshift.orNull)
      .salesforce(salesforce.orNull)
      .snowflake(snowflake.orNull)
      .build()
}
